@@ -131,7 +131,7 @@ func SHA256Sum(data []byte) []byte {
 func SuspiciousSourceDirEntry(base string, info fs.FileInfo) bool {
 	switch info.Mode().Type() {
 	case 0:
-		return strings.HasPrefix(base, Prefix) && knownPrefixedFiles.contains(base)
+		return strings.HasPrefix(base, Prefix) && !knownPrefixedFiles.contains(base)
 	case fs.ModeDir:
 		return strings.HasPrefix(base, Prefix) && base != templatesDirName
 	case fs.ModeSymlink:
