@@ -52,16 +52,16 @@ type templateConfig struct {
 // A Config represents a configuration.
 type Config struct {
 	// Global configuration, settable in the config file.
-	SourceDirAbsPath chezmoi.AbsPath                 `mapstructure:"sourceDir"`
-	DestDirAbsPath   chezmoi.AbsPath                 `mapstructure:"destDir"`
-	Umask            fs.FileMode                     `mapstructure:"umask"`
-	Remove           bool                            `mapstructure:"remove"`
-	Color            *autoBool                       `mapstructure:"color"`
+	Color            autoBool                        `mapstructure:"color"`
 	Data             map[string]interface{}          `mapstructure:"data"`
-	Template         templateConfig                  `mapstructure:"template"`
-	UseBuiltinGit    *autoBool                       `mapstructure:"useBuiltinGit"`
-	Pager            string                          `mapstructure:"pager"`
+	DestDirAbsPath   chezmoi.AbsPath                 `mapstructure:"destDir"`
 	Interpreters     map[string]*chezmoi.Interpreter `mapstructure:"interpreters"`
+	Pager            string                          `mapstructure:"pager"`
+	Remove           bool                            `mapstructure:"remove"`
+	SourceDirAbsPath chezmoi.AbsPath                 `mapstructure:"sourceDir"`
+	Template         templateConfig                  `mapstructure:"template"`
+	Umask            fs.FileMode                     `mapstructure:"umask"`
+	UseBuiltinGit    autoBool                        `mapstructure:"useBuiltinGit"`
 
 	// Global configuration, not settable in the config file.
 	cpuProfile    chezmoi.AbsPath
@@ -202,38 +202,25 @@ func newConfig(options ...configOption) (*Config, error) {
 	}
 
 	c := &Config{
-		bds:          bds,
-		fileSystem:   vfs.OSFS,
-		homeDir:      userHomeDir,
-		Umask:        chezmoi.Umask,
-		Pager:        os.Getenv("PAGER"),
+		// Global configuration, settable in the config file.
+		Color: autoBool{
+			auto: true,
+		},
 		Interpreters: defaultInterpreters,
-		Add: addCmdConfig{
-			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
-			include:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
-			recursive: true,
-		},
-		Diff: diffCmdConfig{
-			Exclude: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
-			include: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
-		},
-		Docs: docsCmdConfig{
-			MaxWidth: 80,
-		},
-		Edit: editCmdConfig{
-			exclude: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
-			include: chezmoi.NewEntryTypeSet(chezmoi.EntryTypeDirs | chezmoi.EntryTypeFiles | chezmoi.EntryTypeSymlinks | chezmoi.EntryTypeEncrypted),
-		},
-		Git: gitCmdConfig{
-			Command: "git",
-		},
-		Merge: mergeCmdConfig{
-			Command: "vimdiff",
-		},
+		Pager:        os.Getenv("PAGER"),
 		Template: templateConfig{
 			Options: chezmoi.DefaultTemplateOptions,
 		},
+		Umask: chezmoi.Umask,
+		UseBuiltinGit: autoBool{
+			auto: true,
+		},
+
+		// Global configuration, not settable in the config file.
+		homeDir:       userHomeDir,
 		templateFuncs: sprig.TxtFuncMap(),
+
+		// Password manager configurations, settable in the config file.
 		Bitwarden: bitwardenConfig{
 			Command: "bw",
 		},
@@ -255,8 +242,43 @@ func newConfig(options ...configOption) (*Config, error) {
 		Vault: vaultConfig{
 			Command: "vault",
 		},
+
+		// Encryption configurations, settable in the config file.
 		AGE: defaultAGEEncryptionConfig,
 		GPG: defaultGPGEncryptionConfig,
+
+		// Password manager data.
+
+		// Command configurations, settable in the config file.
+		Add: addCmdConfig{
+			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
+			include:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
+			recursive: true,
+		},
+		Diff: diffCmdConfig{
+			Exclude: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
+			include: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
+		},
+		Docs: docsCmdConfig{
+			MaxWidth: 80,
+		},
+		Edit: editCmdConfig{
+			exclude: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
+			include: chezmoi.NewEntryTypeSet(chezmoi.EntryTypeDirs | chezmoi.EntryTypeFiles | chezmoi.EntryTypeSymlinks | chezmoi.EntryTypeEncrypted),
+		},
+		Git: gitCmdConfig{
+			Command: "git",
+		},
+		Merge: mergeCmdConfig{
+			Command: "vimdiff",
+			Args: []string{
+				"{{ .Destination }}",
+				"{{ .Source }}",
+				"{{ .Target }}",
+			},
+		},
+
+		// Command configurations, not settable in the config file.
 		apply: applyCmdConfig{
 			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
@@ -323,11 +345,16 @@ func newConfig(options ...configOption) (*Config, error) {
 			recursive: true,
 		},
 
+		// Configuration.
+		fileSystem: vfs.OSFS,
+		bds:        bds,
+
+		// Computed configuration.
+		homeDirAbsPath: homeDirAbsPath,
+
 		stdin:  os.Stdin,
 		stdout: os.Stdout,
 		stderr: os.Stderr,
-
-		homeDirAbsPath: homeDirAbsPath,
 	}
 
 	for key, value := range map[string]interface{}{
@@ -380,8 +407,6 @@ func newConfig(options ...configOption) (*Config, error) {
 		return nil, err
 	}
 	c.DestDirAbsPath = c.homeDirAbsPath
-	c.Color = newAutoBool(c.colorAutoFunc)
-	c.UseBuiltinGit = newAutoBool(c.useBuiltinGitAutoFunc)
 	c._import.destination = c.homeDirAbsPath
 
 	return c, nil
@@ -710,7 +735,13 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 	}
 }
 
-func (c *Config) destAbsPathInfos(sourceState *chezmoi.SourceState, args []string, recursive, follow bool) (map[chezmoi.AbsPath]fs.FileInfo, error) {
+type destAbsPathInfosOptions struct {
+	follow         bool
+	ignoreNotExist bool
+	recursive      bool
+}
+
+func (c *Config) destAbsPathInfos(sourceState *chezmoi.SourceState, args []string, options destAbsPathInfosOptions) (map[chezmoi.AbsPath]fs.FileInfo, error) {
 	destAbsPathInfos := make(map[chezmoi.AbsPath]fs.FileInfo)
 	for _, arg := range args {
 		destAbsPath, err := chezmoi.NewAbsPathFromExtPath(arg, c.homeDirAbsPath)
@@ -720,12 +751,15 @@ func (c *Config) destAbsPathInfos(sourceState *chezmoi.SourceState, args []strin
 		if _, err := destAbsPath.TrimDirPrefix(c.DestDirAbsPath); err != nil {
 			return nil, err
 		}
-		if recursive {
+		if options.recursive {
 			if err := chezmoi.Walk(c.destSystem, destAbsPath, func(destAbsPath chezmoi.AbsPath, info fs.FileInfo, err error) error {
-				if err != nil {
+				switch {
+				case options.ignoreNotExist && errors.Is(err, fs.ErrNotExist):
+					return nil
+				case err != nil:
 					return err
 				}
-				if follow && info.Mode().Type() == fs.ModeSymlink {
+				if options.follow && info.Mode().Type() == fs.ModeSymlink {
 					info, err = c.destSystem.Stat(destAbsPath)
 					if err != nil {
 						return err
@@ -737,12 +771,15 @@ func (c *Config) destAbsPathInfos(sourceState *chezmoi.SourceState, args []strin
 			}
 		} else {
 			var info fs.FileInfo
-			if follow {
+			if options.follow {
 				info, err = c.destSystem.Stat(destAbsPath)
 			} else {
 				info, err = c.destSystem.Lstat(destAbsPath)
 			}
-			if err != nil {
+			switch {
+			case options.ignoreNotExist && errors.Is(err, fs.ErrNotExist):
+				continue
+			case err != nil:
 				return nil, err
 			}
 			if err := sourceState.AddDestAbsPathInfos(destAbsPathInfos, c.destSystem, destAbsPath, info); err != nil {
@@ -756,7 +793,7 @@ func (c *Config) destAbsPathInfos(sourceState *chezmoi.SourceState, args []strin
 func (c *Config) diffFile(path chezmoi.RelPath, fromData []byte, fromMode fs.FileMode, toData []byte, toMode fs.FileMode) error {
 	var sb strings.Builder
 	unifiedEncoder := diff.NewUnifiedEncoder(&sb, diff.DefaultContextLines)
-	color, err := c.Color.Value()
+	color, err := c.Color.Value(c.colorAutoFunc)
 	if err != nil {
 		return err
 	}
@@ -970,11 +1007,11 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 
 	persistentFlags := rootCmd.PersistentFlags()
 
-	persistentFlags.Var(c.Color, "color", "Colorize output")
+	persistentFlags.Var(&c.Color, "color", "Colorize output")
 	persistentFlags.VarP(&c.DestDirAbsPath, "destination", "D", "Set destination directory")
 	persistentFlags.BoolVar(&c.Remove, "remove", c.Remove, "Remove entries from destination directory")
 	persistentFlags.VarP(&c.SourceDirAbsPath, "source", "S", "Set source directory")
-	persistentFlags.Var(c.UseBuiltinGit, "use-builtin-git", "Use builtin git")
+	persistentFlags.Var(&c.UseBuiltinGit, "use-builtin-git", "Use builtin git")
 	for _, key := range []string{
 		"color",
 		"destination",
@@ -1014,7 +1051,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	}
 
 	rootCmd.SetHelpCommand(c.newHelpCmd())
-	rootCmd.AddCommand(
+	for _, cmd := range []*cobra.Command{
 		c.newAddCmd(),
 		c.newApplyCmd(),
 		c.newArchiveCmd(),
@@ -1035,6 +1072,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newImportCmd(),
 		c.newInitCmd(),
 		c.newInternalTestCmd(),
+		c.newMackupCmd(),
 		c.newManagedCmd(),
 		c.newMergeCmd(),
 		c.newPurgeCmd(),
@@ -1048,7 +1086,11 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newUpdateCmd(),
 		c.newUpgradeCmd(),
 		c.newVerifyCmd(),
-	)
+	} {
+		if cmd != nil {
+			rootCmd.AddCommand(cmd)
+		}
+	}
 
 	return rootCmd, nil
 }
@@ -1148,7 +1190,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		c.errorf("warning: %s: %v\n", c.configFileAbsPath, err)
 	}
 
-	color, err := c.Color.Value()
+	color, err := c.Color.Value(c.colorAutoFunc)
 	if err != nil {
 		return err
 	}
